require 'spec_helper'
require 'pry'
require 'dropbox_sdk'

describe Dropscreen do

  describe Dropscreen::Client do

    before do
      `rm -rf artifacts/reference_screenshots` 
      @client = Dropscreen::Client.new(
        remote_base_dir: 'dropscreen',
        local_base_dir: 'artifacts'
       )
    end

    describe '#pull' do

        it 'should pull down all the files in a given directory' do
          @client.pull('reference_screenshots')
          File.exists?('artifacts/reference_screenshots/advisor_page_firefox.gif').should be true  
          File.exists?('artifacts/reference_screenshots/advisor_page_ie9.gif').should be true  
        end

    end

    describe '#exists?' do
      it 'should be false if it doesnt exist' do
        @client.exists?('flibble/flibble').should be false
      end
      it 'should be false if it is deleted' do 
        allow(@client).to receive(:exists?).and_return({'is_deleted' => true});
      end
      it 'should be true if it exists' do
        @client.exists?('reference_screenshots').should be true
      end
    end


    describe '#push' do
      
      it 'should create the destination folder if it doesnt already exist' do
        @client.push('screenshots_generated_this_run')
        new_folder = @client.client.metadata('dropscreen/screenshots_generated_this_run/')
        fail "Folder wasn't created" unless new_folder['is_dir']
      end

      it 'should not create the destination folder if it already exists' do
        @client.push('screenshots_generated_this_run')
        @client.push('screenshots_generated_this_run')
      end


      it 'should push up all the files in a given directory' do
        @client.push('screenshots_generated_this_run')
        contents = @client.client.metadata('dropscreen/screenshots_generated_this_run/')['contents']
      end
    end

    describe '#remove' do 
      it 'should remove a directory' do 
        @client.push('screenshots_generated_this_run')
        expect(@client.remove('screenshots_generated_this_run')).to be true
      end

      it 'should remove a file' do 
        FileUtils.touch('artifacts/screenshots_generated_this_run/little_lonely_file')
        @client.push('screenshots_generated_this_run')
        expect(@client.remove('screenshots_generated_this_run/little_lonely_file')).to be true
      end

      it 'should not complain if you try to delete a non existent folder' do 
        @client.remove('non_existent_folder')
        expect(@client.remove('non_existent_folder')).to be true
      end

      it 'should not complain if you try to delete a non existent file' do 
        @client.push('screenshots_generated_this_run')
        @client.remove('screenshot_generated_this_run/non_existent_file')
        expect(@client.remove('screenshot_generated_this_run/non_existent_file')).to be true
      end

    end


  end


end
